#!/bin/bash

####################

EXE=../../../PROFESS3.0m5/PROFESS

########################################

### OFDFT
for kefunc in VT84F APBEF PBETWF KST2 TSGA TTF #
do
# density (in g/cm^3)
for R in 0.40 0.45 0.50 0.55 0.60 0.65 0.70 0.75 0.80
do
# Temperature (in K)
for T in 100 #1000 ################################
do
# ecut
for ecut in 3000 #
do
###############

dime=two #odd #two
conv=3 #1-TOLE 2-TOLP 3-BOTH 4-EITHER
tole=0.03e-5 #1.e-3
tolp=1.e-5 #1.e-3

mu=1.000
method=ntn
exch=lda
PSP=H.recpot

kinetic=$kefunc

if [ $kefunc = "hVW+TTF"  ] ; then kinetic=hVWTF mu=1.000; fi
if [ $kefunc = "hVWx0.1111+TTF"  ] ; then kinetic=hVWTF mu=0.11111111111; fi
if [ $kefunc = "TSGA"            ] ; then kinetic=hVWTF mu=0.11111111111; fi

echo " Starting calculation:" 
echo " kefunc=" $kefunc "+ exch=" $exch #" kinetic=" $kinetic " mu=" $mu
echo " ecut=" $ecut "eV"

DIR='H-sc_2X2X2r0-'$exch'-'$method'-'$ecut'eV-'$dime'-T'$T'K'
if [ -d ../"$DIR" ]
then
  cd ../$DIR
else
  mkdir ../$DIR
  cd ../$DIR
fi
rm -rf $PSP;ln -s ../$PSP

bohr2ang=0.529177249
ang2bohr=1.889725989
LATR1=3.412117847 # R=0.33706 g/cm^3 for LATCONST=1.0 Ang
### for ofdft: LATCONST in angstr
LATCONST=`echo $R $LATR1 | awk '{print $2*(0.33706/$1)^(1./3.)}'`

SCL=$LATCONST
echo " R=" $R " LATCONST=" $LATCONST " Ang"

FN=$kefunc'+XC.T'$T'.-.R'$R

echo " T=" $T "K"

cat > $FN.inpt <<EOF
ecut $ecut                      # The kinetic energy cutoff
parameter temp $T
mini rho #cel #rho # cel #for #rho
#
method  $method
conv $conv #1-TOLE 2-TOLP 3-BOTH 4-EITHER
tole $tole #1.e-4 #1.e-6
tolp $tolp #1.e-3 #1.e-5
#method ion qui #fix #qui ste con 
#
kinetic  $kinetic #TWP0F hVWTF TMC01 TGG01
#parameter temp 100000.
parameter lambda 1.0 #1 
parameter mu $mu #0.11111111111 #0.2 #1 #0.2
#parameter alpha 1.2060113295832982827348622781219
#parameter beta 0.46065533708336838393180438854479
##parameter rho0 0.191917673799676
##parameter rhoS 0.191917673799676
#
#
exch $exch #pbe #lda #pbe
#pauli mcpbe2 #pbetw #mcpbe2
#
#prin den
geometryfile inp.ion
print minimizer density 2   # Print lots of detail about electronic minimization 
#print minimizer geo 4 
prin str
#prin for sep

dime $dime #two #all #two #all #two #all #two #all #two #even !two
EOF

cat > inp.ion << EOF
%BLOCK LATTICE_CART
1.0            0             0
0              1.0           0
0              0             1.0
$SCL
%END BLOCK LATTICE_CART
%BLOCK POSITIONS_CART
H        0.25         0.25         0.25
H        0.75         0.25         0.25
H        0.25         0.75         0.25
H        0.75         0.75         0.25
H        0.25         0.25         0.75
H        0.75         0.25         0.75
H        0.25         0.75         0.75
H        0.75         0.75         0.75
%END BLOCK POSITIONS_CART
%BLOCK SPECIES_POT
    H  $PSP                                                                
%END BLOCK SPECIES_POT
EOF

$EXE  $FN > out

echo " Done"
echo ""

done
done
done
done
