#!/bin/bash
#

####################

EXE=../../../espresso-5.2.1m5/bin/pw.x

########################################

# density
for R in 2.37 ################################
do
# Temperature
for T in 20000 ################################
do
####

### QE
# K-points
KP=G #
NBND=170
ECUT=15.0
EXC=ksdt
NRAISE=10

### OFDFT
#system:
atom=Al
amu=26.981539
NATOM=108
SYS=$atom$NATOM
PSP=$atom.recpot
amu=26.981539
#functionals:
kefunc=VT84F
exch=ksdt
#parameters:
ecut=500
dime=two #even
conv=3 #1-TOLE 2-TOLP 3-BOTH 4-EITHER
tole=0.03e-3 #1.e-3
tolp=1.e-3 #1.e-3
method=ntn #ncg
maxirho=50 #1200

kinetic=$kefunc
if [ $kefunc = "hVW+TTF"  ] ; then kinetic=hVWTF mu=1.000; fi
if [ $kefunc = "hVWx0.1111+TTF"  ] ; then kinetic=hVWTF mu=0.11111111111; fi

echo " kefunc=" $kefunc
echo " ecut=" $ecut " exch=" $exch " NRAISE=" $NRAISE

DIR=$kefunc'+'$exch.ecut$ecut.R$R.T$T.$method.nr$NRAISE
if [ -d ../"$DIR" ]
then
  cd ../$DIR
else
  mkdir ../$DIR
  cd ../$DIR
fi
rm -rf $PSP
ln -s ../$PSP

### INITIAL POSITIONS FILE
posini=mfcc-Al108.frac
cp ../scripts/$posini .
#posini=pos.last
echo " posini=" $posini
sed '1d' $posini > pos.in
posini=pos.in
echo " posini=" $posini

bohr2ang=0.529177249
ang2bohr=1.889725989
amu2g=1.6605402 # times 10^-24, 1 atomic mass unit in gramm
M=`echo $NATOM $amu $amu2g | awk '{print $1*$2*$3}'` # total mass in g times 10^-24
LATCONST=`echo $M $R | awk '{print ($1/$2)^(1./3.)}'` # lattice constant in Ang=cm x 10^-8
LATCONST=`echo $LATCONST $ang2bohr | awk '{print $1*$2}'` # lattice constan Ang --> Bohr

echo " R=" $R " LATCONST=" $LATCONST " Bohr"

### added from Vasp script
time=800 #200.0 #total simulation time in fs
dt100K=5.0 #4.0 #time step in fs for T=100K
###
dt=`echo $dt100K $T | awk '{print $1*(100./$2)^0.5}'` #scale it for given temperature T
dt=`echo $dt $R     | awk '{print $1*(1./$2)^(1./3.)}'` #scale it for given Rho, higher Rho, smaller dt
time=`echo $time $T | awk '{print 2.5*$1*(10000./$2)^0.5}'` #scale time for given temperature T
time=`echo $time    | cut -d '.' -f1` # get integer part
dtas=`echo $dt      | awk '{print $1*1000}'` #time-step in as
dtas=`echo $dtas    | cut -d '.' -f1` # get integer part
TIMESTEP=$dt

  NSW=`echo $time $dt | awk '{print $1/$2}'` # NSW=time/dt
  NSW=`echo $NSW | cut -d '.' -f1` # get integer part
NMDSTEP=100 #

echo " dt100K=" $dt100K "fs"
echo " T=" $T "K time=" $time "fs dt=" $dt "fs NMDSTEP=" $NMDSTEP

### time step fs--> Ry
### 1 a.u.=4.8378x10^-17 s=4.8378x10^-2 fs
### 1 fs= 100/4.8378 a.u.=200/4.8378 Ry
dt=`echo $TIMESTEP | awk '{print $1*100./4.8378}'`
echo " dt=" $dt "Ry"

echo " NBND=" $NBND

FN='R'$R'.T'$T'.'$kefunc'+'$exch'.ecut'$ecut'.NMDSTEP'$NMDSTEP'.dt'$dtas'as.nr'$NRAISE

#echo " T=" $T "K"
TEMP=`echo $T | awk '{print $1*8.617343e-5/13.6057}'`

cat > ofdft.inpt <<EOF
ecut $ecut                      # The kinetic energy cutoff
parameter tel $T
mini rho #cel #rho # cel #for #rho
#
method $method
maxi rho $maxirho
conv $conv #1-TOLE 2-TOLP 3-BOTH 4-EITHER
tole $tole #1.e-4 #1.e-6
tolp $tolp #1.e-3 #1.e-5
#rhou
#method ion qui #fix #qui ste con 
#
kinetic  $kinetic #TWP0F hVWTF TMC01 TGG01
#parameter temp 100000.
#parameter lambda 1.0 #1 
#parameter mu $mu #0.11111111111 #0.2 #1 #0.2
#parameter nu $nu
#parameter nu2 $nu2
#parameter alpha 1.2060113295832982827348622781219
#parameter beta 0.46065533708336838393180438854479
##parameter rho0 0.191917673799676
##parameter rhoS 0.191917673799676
#
#
exch $exch #pbe #lda #pbe
#pauli mcpbe2 #pbetw #mcpbe2
#
#prin den
geometryfile inp.ion
print minimizer density 2   # Print lots of detail about electronic minimization 
#print minimizer geo 4 
prin str
prin for sep

nndi -1.d0 # Nearest Neighbour Distance in Ang, turn it off.
nnbi -1.d0 # Use binning to compute the minimum nearest neighbor distance, turn it off.

dime $dime #even #all #two #all #two #all #two #all #two #even !two
EOF

cat > tmp1.in <<EOF
&control
   calculation = 'md'
   restart_mode = 'from_scratch'
   pseudo_dir = '..'
   tstress = .TRUE.
   useofdft = .TRUE.,
   nstep = $NMDSTEP,
   dt=$dt,
   verbosity = 'low'
/
&system
   input_dft=$EXC,
   ibrav = 0, 
   celldm(1) = $LATCONST,
   nosym = .TRUE.,
   nat = $NATOM, 
   ntyp = 1,
   nbnd = $NBND,
   ecutwfc = $ECUT,
   occupations = 'smearing',
   smearing = 'fd',
   degauss = $TEMP
/
&electrons
   diagonalization = 'david'
/
 &ions
   ion_dynamics = 'verlet',
   ion_temperature ='andersen',
   tempw = $T,
   nraise = $NRAISE
/
   CELL_PARAMETERS { alat }
   1.0 0.0 0.0
   0.0 1.0 0.0
   0.0 0.0 1.0
ATOMIC_SPECIES
 Al 26.981539 Al.UPF
ATOMIC_POSITIONS alat
EOF

## Gamma-point only
if [ "$KP" == "G" ]; then
 echo "k-mesh: Gamma-point only"
 cat > tmp2.in <<EOF     
 K_POINTS gamma
EOF
## Baldareschi medium point
elif [ "$KP" == "0.25" ]; then
 echo "k-mesh:" $KP"x"$KP"x"$KP
 cat > tmp2.in <<EOF     
 K_POINTS tpiba
 1
   $KP $KP $KP 2.
EOF
## KPxKPxKP
else 
 echo "k-mesh:" $KP"x"$KP"x"$KP
 cat > tmp2.in <<EOF     
 K_POINTS automatic
   $KP $KP $KP 0 0 0
EOF
fi

cat tmp1.in $posini tmp2.in > $SYS.$FN.in
rm -rf tmp1.in tmp2.in

$EXE < $SYS.$FN.in > $SYS.$FN.out

rm -rf pwscf.save.$FN
mv pwscf.save pwscf.save.$FN
#rm -rf pwscf.save.$FN
mv pwscf.md pwscf.$FN.md
mv pwscf.msd.dat pwscf.msd.$SYS.$FN.dat
mv pwscf.rdf.dat pwscf.rdf.$SYS.$FN.dat
rm -rf pwscf.wfc*
rm -rf pwscf.old*
rm -rf pwscf.igk*
rm -rf pwscf.paw
mv md.xyz md.$SYS.$FN.xyz

cat > calc_details.txt <<EOF
#dens (g/cm^3) temperature (K) pseudopotential
$R $T Al.UPF
EOF

#cd ..
done
#cd ..
done
