#!/bin/bash

####################


EXE=../../../espresso-5.2.1m5/bin/pw.x

########################################

# HF ##
x_gamma_extrapolation=".TRUE."
exxdiv_treatment="gygi-baldereschi"
if [ ! -z "$1" ] ; then exxdiv_treatment="$1" ; fi
if [ "$exxdiv_treatment" = "vcut_ws" ] ; then x_gamma_extrapolation=.FALSE. ; fi
if [ "$exxdiv_treatment" = "vcut_spheric" ] ; then x_gamma_extrapolation=.FALSE. ; fi
ecutvcut=0.7

nq=1
# K-points
KP=1

####
# density (in g/cm^3)
for R in 0.983 ################################
do
# Temperature (in K)
for T in 125000 ################################
do
####

### QE
NBND=128
ECUT=75.0
EXC=ksdt
NRAISE=20

### OFDFT
ecut=3000
conv=3 #1-TOLE 2-TOLP 3-BOTH 4-EITHER
tole=1.e-5 #1.e-3
tolp=1.e-4 #1.e-3
method=ntn #stn #scg # stn

mu=1.000
kefunc=VT84F #<-- TVT84F
exch=ksdt
PSP=H.recpot

kinetic=$kefunc
if [ $kefunc = "hVW+TTF"  ] ; then kinetic=hVWTF mu=1.000; fi
if [ $kefunc = "hVWx0.1111+TTF"  ] ; then kinetic=hVWTF mu=0.11111111111; fi
if [ $kefunc = "TSGA"            ] ; then kinetic=hVWTF mu=0.11111111111; fi

echo " kefunc=" $kefunc
echo " ecut=" $ecut " exch=" $exch " NRAISE=" $NRAISE

DIR=$kefunc'+'$exch.ecut$ecut.R$R.T$T.$method.nr$NRAISE
mkdir ../$DIR
cd    ../$DIR
ln -s ../$PSP

### INITIAL POSITIONS FILE
posini=../scripts/msc-H128.frac #
posini=../scripts/pos.last-TTF.R0.983.T125000.101steps
#posini=pos.last
echo " posini=" $posini
sed '1d' $posini > pos.in
posini=pos.in
echo " posini=" $posini

bohr2ang=0.529177249
ang2bohr=1.889725989
LATR1=3.412117847 # Ang R=0.33706 g/cm^3
LATR1=6.824235694  # Ang R=0.33706 g/cm^3 64 atoms ! =3.412117847*2
LATR1=10.236353541 # Ang R=0.33706 g/cm^3 216 atoms ! =3.412117847*3
LATR1=8.5979982010 # Ang R=0.33706 g/cm^3 128 atoms ! =3.412117847*2.51984210 (128=8*2.51984210^3)
LATCONST=`echo $R $LATR1 $ang2bohr | awk '{print $2*(0.33706/$1)^(1./3.)*$3}'`
#convert LAT_H to LAT_D: LAT_D=LAT_H*(m_D/m_H)^1/3
#LATCONST=`echo $LATCONST | awk '{print $1*(2.01410178/1.00794)^(1./3.)}'`

echo " R=" $R " LATCONST=" $LATCONST " Bohr"

### added from Vasp script
time=800 #200.0 #total simulation time in fs
dt100K=2 #4.0 #time step in fs for T=100K
###
dt=`echo $dt100K $T | awk '{print $1*(100./$2)^0.5}'` #scale it for given temperature T
dt=`echo $dt $R     | awk '{print $1*(1./$2)^(1./3.)}'` #scale it for given Rho, higher Rho, smaller dt
time=`echo $time $T | awk '{print 2.5*$1*(10000./$2)^0.5}'` #scale time for given temperature T
time=`echo $time    | cut -d '.' -f1` # get integer part
dtas=`echo $dt      | awk '{print $1*1000}'` #time-step in as
dtas=`echo $dtas    | cut -d '.' -f1` # get integer part
TIMESTEP=$dt

  NSW=`echo $time $dt | awk '{print $1/$2}'` # NSW=time/dt
  NSW=`echo $NSW | cut -d '.' -f1` # get integer part
NMDSTEP=10 #$NSW

echo " dt100K=" $dt100K "fs"
echo " T=" $T "K time=" $time "fs dt=" $dt "fs NMDSTEP=" $NMDSTEP

### time step fs--> Ry
### 1 a.u.=4.8378x10^-17 s=4.8378x10^-2 fs
### 1 fs= 100/4.8378 a.u.=200/4.8378 Ry
dt=`echo $TIMESTEP | awk '{print $1*100./4.8378}'`
echo " dt=" $dt "Ry"

FN='R'$R'.T'$T'.'$kefunc'+'$exch'.ecut'$ecut'.NMDSTEP'$NMDSTEP'.dt'$dtas'as.nr'$NRAISE

#echo " T=" $T "K"
TEMP=`echo $T | awk '{print $1*8.617343e-5/13.6057}'`

cat > ofdft.inpt <<EOF
ecut $ecut                      # The kinetic energy cutoff
parameter temp $T
mini rho #cel #rho # cel #for #rho
#
method $method
conv $conv #1-TOLE 2-TOLP 3-BOTH 4-EITHER
tole $tole #1.e-4 #1.e-6
tolp $tolp #1.e-3 #1.e-5
#rhou
#method ion qui #fix #qui ste con 
#
kinetic  $kinetic #TWP0F hVWTF TMC01 TGG01
#parameter temp 100000.
parameter lambda 1.0 #1 
parameter mu $mu #0.11111111111 #0.2 #1 #0.2
#parameter alpha 1.2060113295832982827348622781219
#parameter beta 0.46065533708336838393180438854479
##parameter rho0 0.191917673799676
##parameter rhoS 0.191917673799676
#
#
exch $exch #pbe #lda #pbe
#pauli mcpbe2 #pbetw #mcpbe2
#
#prin den
geometryfile inp.ion
print minimizer density 2   # Print lots of detail about electronic minimization 
#print minimizer geo 4 
prin str
prin for sep

nndi -1.d0 # Nearest Neighbour Distance in Ang, turn it off.
nnbi -1.d0 # Use binning to compute the minimum nearest neighbor distance, turn it off.

dime two #odd #two #all #two #all #two #all #two #all #two #even !two
EOF

cat > tmp1.in <<EOF
&control
   calculation = 'md'
   restart_mode = 'from_scratch'
   pseudo_dir = '..'
   tstress = .TRUE.,
   useofdft = .TRUE.,
   nstep = $NMDSTEP,
   dt=$dt,
   verbosity = 'low'
/
&system
   input_dft=$EXC,
   ibrav = 0, 
   celldm(1) = $LATCONST,
   nosym = .TRUE.,
   nat = 128, 
   ntyp = 1,
   nbnd = $NBND,
   ecutwfc = $ECUT,
   occupations = 'smearing',
   smearing = 'fd',
   degauss = $TEMP
/
&electrons
   diagonalization = 'david'
/
 &ions
   ion_dynamics = 'verlet',
   ion_temperature ='andersen',
   tempw = $T,
   nraise = $NRAISE
/
   CELL_PARAMETERS { alat }
   1.0 0.0 0.0
   0.0 1.0 0.0
   0.0 0.0 1.0
ATOMIC_SPECIES
 H 1.00794 H.UPF
ATOMIC_POSITIONS alat
EOF
  
cat > tmp2.in <<EOF   
K_POINTS gamma
EOF

cat tmp1.in $posini tmp2.in > H.$FN.in
rm -rf tmp1.in tmp2.in

#########$EXE < H.$FN.in > H.$FN.out
$EXE < H.$FN.in > H.$FN.out

#rm -rf pwscf.save.$FN
#mv pwscf.save pwscf.save.$FN
#rm -rf pwscf.save.$FN
mv pwscf.md pwscf.$FN.md
mv pwscf.msd.dat pwscf.msd.$FN.dat
mv pwscf.rdf.dat pwscf.rdf.$FN.dat
rm -rf pwscf.wfc*
rm -rf pwscf.igk*
rm -rf pwscf.paw
mv md.xyz md.$FN.xyz
mv ofdft.out ofdft.$FN.out

cat > calc_details.txt <<EOF
#dens (g/cm^3) temperature (K) pseudopotential
$R $T $PSP
EOF

#cd ..
done
#cd ..
done
